@@ -7,22 +7,22 @@ var list_across0 = [
 ];
 var list_up0 = [
 'cppad.xml',
-'appendix.xml',
 'speed.xml',
 'speed_cppad.xml',
 'cppad_det_minor.cpp.xml'
 ];
 var list_down3 = [
-'faq.xml',
+'install.xml',
+'introduction.xml',
+'ad.xml',
+'adfun.xml',
+'preprocessor.xml',
+'multi_thread.xml',
+'library.xml',
+'ipopt_solve.xml',
+'example.xml',
 'speed.xml',
-'theory.xml',
-'glossary.xml',
-'bib.xml',
-'bugs.xml',
-'wishlist.xml',
-'whats_new.xml',
-'deprecated.xml',
-'license.xml'
+'appendix.xml'
 ];
 var list_down2 = [
 'speed_main.xml',
@@ -43,7 +43,8 @@ var list_down1 = [
 'cppad_sparse_jacobian.cpp.xml'
 ];
 var list_current0 = [
-'cppad_det_minor.cpp.xml#link_det_minor'
+'cppad_det_minor.cpp.xml#Specifications',
+'cppad_det_minor.cpp.xml#Implementation'
 ];
 function choose_across0(item)
 {	var index          = item.selectedIndex;
