@@ -14,7 +14,6 @@ var list_up0 = [
 ];
 var list_down3 = [
 'faq.xml',
-'speed.xml',
 'theory.xml',
 'glossary.xml',
 'bib.xml',
@@ -22,6 +21,7 @@ var list_down3 = [
 'wishlist.xml',
 'whats_new.xml',
 'deprecated.xml',
+'compare_c.xml',
 'license.xml'
 ];
 var list_down2 = [
@@ -37,7 +37,8 @@ var list_down1 = [
 'atanreverse.xml',
 'asinreverse.xml',
 'acosreverse.xml',
-'tan_reverse.xml'
+'tan_reverse.xml',
+'erf_reverse.xml'
 ];
 function choose_across0(item)
 {	var index          = item.selectedIndex;
