@@ -32,7 +32,8 @@ var list_down1 = [
 'funeval.xml',
 'drivers.xml',
 'funcheck.xml',
-'optimize.xml'
+'optimize.xml',
+'check_for_nan.xml'
 ];
 var list_down0 = [
 'fun_check.cpp.xml'
