@@ -33,7 +33,8 @@ var list_down2 = [
 'memory_leak.xml',
 'epsilon.xml',
 'test_vector.xml',
-'cppad_ipopt_nlp.xml'
+'cppad_ipopt_nlp.xml',
+'old_atomic.xml'
 ];
 var list_down1 = [
 'omp_max_num_threads.xml',
